package com.diagbot.aggregate;

import com.diagbot.dto.AverageStatisticsDTO;
import com.diagbot.facade.ConsoleFacade;
import com.diagbot.facade.HomePageFacade;
import com.diagbot.util.ListUtil;
import com.diagbot.vo.FilterVO;
import com.google.common.collect.Lists;
import io.github.lvyahui8.spring.annotation.DataConsumer;
import io.github.lvyahui8.spring.annotation.DataProvider;
import io.github.lvyahui8.spring.annotation.InvokeParameter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2020/4/23 14:11
 */
@Component
public class AverageStatisticsAggregate {
    @Autowired
    private HomePageFacade homePageFacade;
    @Autowired
    private ConsoleFacade consoleFacade;

    @DataProvider("setAllAverage")
    public Map<String, Object> setAllResult(
            @InvokeParameter("filterVO") FilterVO filterVO,
            @DataConsumer("getAverageDayNum") List<AverageStatisticsDTO> averageDayNumList,
            @DataConsumer("getAverageFee") List<AverageStatisticsDTO> averageFeeList) {
        Map<String, Object> retMap = new LinkedHashMap<>();
        if (ListUtil.isNotEmpty(averageDayNumList)) {
            retMap.put("平均住院日", averageDayNumList);
        }
        if (ListUtil.isNotEmpty(averageFeeList)) {
            retMap.put("平均住院费用", averageFeeList);
        }
        return retMap;
    }

    /**
     * 平均住院天数
     *
     * @param filterVO
     * @return
     */
    @DataProvider("getAverageDayNum")
    public List<AverageStatisticsDTO> getAverageDayNum(@InvokeParameter("filterVO") FilterVO filterVO) {
        List<AverageStatisticsDTO> retAverageDayNumList = Lists.newLinkedList();
        List<AverageStatisticsDTO> averageDayNumList = homePageFacade.getAverageDayNum(filterVO);
        if (filterVO.getLimitCount() == null || filterVO.getLimitCount().equals(0)) {
            filterVO.setLimitCount(10);
        }
        Integer limitCount = filterVO.getLimitCount();
        //平均住院日
        if (ListUtil.isNotEmpty(averageDayNumList)) {
            retAverageDayNumList = consoleFacade.getLimitAverageList(averageDayNumList, limitCount);
        }
        return retAverageDayNumList;
    }

    /**
     * 平均住院费用
     *
     * @param filterVO
     * @return
     */
    @DataProvider("getAverageFee")
    public List<AverageStatisticsDTO> getAverageFee(@InvokeParameter("filterVO") FilterVO filterVO) {
        List<AverageStatisticsDTO> retAverageFeeList = Lists.newLinkedList();
        List<AverageStatisticsDTO> averageFeeList = homePageFacade.getAverageFee(filterVO);
        if (filterVO.getLimitCount() == null || filterVO.getLimitCount().equals(0)) {
            filterVO.setLimitCount(10);
        }
        Integer limitCount = filterVO.getLimitCount();
        //平均住院费用
        if (ListUtil.isNotEmpty(averageFeeList)) {
            retAverageFeeList = consoleFacade.getLimitAverageList(averageFeeList, limitCount);
        }
        return retAverageFeeList;
    }
}